package com.ruoyi.bst.fault.service.impl;

import com.ruoyi.bst.device.domain.DeviceVO;
import com.ruoyi.bst.device.service.DeviceService;
import com.ruoyi.bst.fault.domain.Fault;
import com.ruoyi.bst.fault.domain.FaultVO;
import com.ruoyi.bst.fault.domain.enums.FaultStatus;
import com.ruoyi.bst.fault.service.FaultConverter;
import com.ruoyi.bst.fault.service.FaultService;
import com.ruoyi.bst.order.domain.OrderVO;
import com.ruoyi.bst.order.service.OrderService;
import com.ruoyi.common.core.domain.vo.UserVO;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.system.user.service.UserService;
import org.checkerframework.checker.units.qual.A;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class AbnormalConverterImpl implements FaultConverter {

    @Autowired
    private FaultService faultService;

    @Autowired
    private DeviceService deviceService;

    @Autowired
    private OrderService orderService;

    @Autowired
    private UserService userService;

    @Override
    public Fault toPo(FaultVO fault) {
        DeviceVO device = deviceService.selectDeviceBySn(fault.getVehicleCode());
        ServiceUtil.assertion(device == null, "设备不存在");

        Fault po = new Fault();
        po.setFaultSite(fault.getFaultSite());
        po.setVehicleCode(fault.getVehicleCode());
        po.setPicture(fault.getPicture());
        po.setFaultDetail(fault.getFaultDetail());
        po.setCreateBy(fault.getCreateBy());
        po.setAppealStatus(FaultStatus.PENGDING.getCode());
        po.setCreateTime(DateUtils.getNowDate());
        po.setUserName(fault.getCreateBy());
        po.setUserId(fault.getUserId());

        if (device.getOrderId() != null && fault.getOrderId().equals(device.getOrderId())) {
            po.setOrderId(device.getOrderId());
            OrderVO order = orderService.selectOrderById(device.getOrderId());
            if (order.getEndTime() != null) {
                po.setOrderEndTime(DateUtils.toDate(order.getEndTime()));
            }
        }

        String vehicleNum = device.getVehicleNum();
        if (vehicleNum != null) {
            po.setVehicleNum(vehicleNum);
        }
        return po;
    }
}
